==> RsCMX_Signaling-4.0.120.tar.gz: RsCMX_Signaling-4.0.120/RsCMX_Signaling/Implementations/Configure/Signaling/Lte/Cell/Mconfig/Cdeployment.py <==
from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CdeploymentCls:
	"""Cdeployment commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cdeployment", core, parent)

	def set(self, cell_name: str, cell_deployment: enums.CellDeployment) -> None:
		"""SCPI: [CONFigure]:SIGNaling:LTE:CELL:MCONfig:CDEPloyment \n
		Snippet: driver.configure.signaling.lte.cell.mconfig.cdeployment.set(cell_name = '1', cell_deployment = enums.CellDeployment.REAL) \n
		Selects whether the cell is a real cell or a virtual cell. \n
			:param cell_name: No help available
			:param cell_deployment: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('cell_name', cell_name, DataType.String), ArgSingle('cell_deployment', cell_deployment, DataType.Enum, enums.CellDeployment))
		self._core.io.write(f'CONFigure:SIGNaling:LTE:CELL:MCONfig:CDEPloyment {param}'.rstrip())

	# noinspection PyTypeChecker
	def get(self, cell_name: str) -> enums.CellDeployment:
		"""SCPI: [CONFigure]:SIGNaling:LTE:CELL:MCONfig:CDEPloyment \n
		Snippet: value: enums.CellDeployment = driver.configure.signaling.lte.cell.mconfig.cdeployment.get(cell_name = '1') \n
		Selects whether the cell is a real cell or a virtual cell. \n
			:param cell_name: No help available
			:return: cell_deployment: No help available"""
		param = Conversions.value_to_quoted_str(cell_name)
		response = self._core.io.query_str(f'CONFigure:SIGNaling:LTE:CELL:MCONfig:CDEPloyment? {param}')
		return Conversions.str_to_scalar_enum(response, enums.CellDeployment)

==> RsCMX_Signaling-7.70.0.tar.gz: RsCMX_Signaling-7.70.0/RsCMX_Signaling/Implementations/Configure/Signaling/Lte/Cell/Mconfig/Cdeployment.py <==
from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CdeploymentCls:
	"""Cdeployment commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cdeployment", core, parent)

	def set(self, cell_name: str, cell_deployment: enums.CellDeployment) -> None:
		"""SCPI: [CONFigure]:SIGNaling:LTE:CELL:MCONfig:CDEPloyment \n
		Snippet: driver.configure.signaling.lte.cell.mconfig.cdeployment.set(cell_name = 'abc', cell_deployment = enums.CellDeployment.REAL) \n
		Selects whether the cell is a real cell or a virtual cell. \n
			:param cell_name: No help available
			:param cell_deployment: No help available
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('cell_name', cell_name, DataType.String), ArgSingle('cell_deployment', cell_deployment, DataType.Enum, enums.CellDeployment))
		self._core.io.write(f'CONFigure:SIGNaling:LTE:CELL:MCONfig:CDEPloyment {param}'.rstrip())

	# noinspection PyTypeChecker
	def get(self, cell_name: str) -> enums.CellDeployment:
		"""SCPI: [CONFigure]:SIGNaling:LTE:CELL:MCONfig:CDEPloyment \n
		Snippet: value: enums.CellDeployment = driver.configure.signaling.lte.cell.mconfig.cdeployment.get(cell_name = 'abc') \n
		Selects whether the cell is a real cell or a virtual cell. \n
			:param cell_name: No help available
			:return: cell_deployment: No help available"""
		param = Conversions.value_to_quoted_str(cell_name)
		response = self._core.io.query_str(f'CONFigure:SIGNaling:LTE:CELL:MCONfig:CDEPloyment? {param}')
		return Conversions.str_to_scalar_enum(response, enums.CellDeployment)
